==> eam-wshub-proxyclient-11.6-0-sources.jar: net/datastream/schemas/mp_functions/mp7006_001/MP7006_DeletePMScheduleEquipment_001.java <==

package net.datastream.schemas.mp_functions.mp7006_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.BaseSchemaRequestElement;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.PMSCHEDULEEQUIPMENTID;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;extension base="{http://schemas.datastream.net/MP_fields}BaseSchemaRequestElement">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PMSCHEDULEEQUIPMENTID"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Delete" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="PMScheduleEquipment" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="callname" type="{http://www.w3.org/2001/XMLSchema}string" default="DeletePMScheduleEquipment" />
 *       &lt;attribute name="action" type="{http://www.w3.org/2001/XMLSchema}string" default="DeletePMScheduleEquipment" />
 *       &lt;attribute name="confirm_deleteall_pms_equip" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="confirmed" />
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "pmscheduleequipmentid"
})
@XmlRootElement(name = "MP7006_DeletePMScheduleEquipment_001")
public class MP7006_DeletePMScheduleEquipment_001
    extends BaseSchemaRequestElement
{

    @XmlElement(name = "PMSCHEDULEEQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected PMSCHEDULEEQUIPMENTID pmscheduleequipmentid;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "callname")
    protected String callname;
    @XmlAttribute(name = "action")
    protected String action;
    @XmlAttribute(name = "confirm_deleteall_pms_equip")
    protected String confirm_Deleteall_Pms_Equip;

    /**
     * Obtient la valeur de la propriété pmscheduleequipmentid.
     * 
     * @return
     *     possible object is
     *     {@link PMSCHEDULEEQUIPMENTID }
     *     
     */
    public PMSCHEDULEEQUIPMENTID getPMSCHEDULEEQUIPMENTID() {
        return pmscheduleequipmentid;
    }

    /**
     * Définit la valeur de la propriété pmscheduleequipmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link PMSCHEDULEEQUIPMENTID }
     *     
     */
    public void setPMSCHEDULEEQUIPMENTID(PMSCHEDULEEQUIPMENTID value) {
        this.pmscheduleequipmentid = value;
    }

    /**
     * Obtient la valeur de la propriété verb.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.DELETE;
        } else {
            return verb;
        }
    }

    /**
     * Définit la valeur de la propriété verb.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Obtient la valeur de la propriété noun.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.PM_SCHEDULE_EQUIPMENT;
        } else {
            return noun;
        }
    }

    /**
     * Définit la valeur de la propriété noun.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Obtient la valeur de la propriété version.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Définit la valeur de la propriété version.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Obtient la valeur de la propriété callname.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCallname() {
        if (callname == null) {
            return "DeletePMScheduleEquipment";
        } else {
            return callname;
        }
    }

    /**
     * Définit la valeur de la propriété callname.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCallname(String value) {
        this.callname = value;
    }

    /**
     * Obtient la valeur de la propriété action.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAction() {
        if (action == null) {
            return "DeletePMScheduleEquipment";
        } else {
            return action;
        }
    }

    /**
     * Définit la valeur de la propriété action.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAction(String value) {
        this.action = value;
    }

    /**
     * Obtient la valeur de la propriété confirm_Deleteall_Pms_Equip.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Deleteall_Pms_Equip() {
        if (confirm_Deleteall_Pms_Equip == null) {
            return "confirmed";
        } else {
            return confirm_Deleteall_Pms_Equip;
        }
    }

    /**
     * Définit la valeur de la propriété confirm_Deleteall_Pms_Equip.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Deleteall_Pms_Equip(String value) {
        this.confirm_Deleteall_Pms_Equip = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_functions/mp7006_001/MP7006_DeletePMScheduleEquipment_001.java <==

package net.datastream.schemas.mp_functions.mp7006_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.BaseSchemaRequestElement;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.PMSCHEDULEEQUIPMENTID;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;extension base="{http://schemas.datastream.net/MP_fields}BaseSchemaRequestElement">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PMSCHEDULEEQUIPMENTID"/>
 *       &lt;/sequence>
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Delete" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="PMScheduleEquipment" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *       &lt;attribute name="callname" type="{http://www.w3.org/2001/XMLSchema}string" default="DeletePMScheduleEquipment" />
 *       &lt;attribute name="action" type="{http://www.w3.org/2001/XMLSchema}string" default="DeletePMScheduleEquipment" />
 *       &lt;attribute name="confirm_deleteall_pms_equip" type="{http://schemas.datastream.net/MP_fields}CONFIRMATION_Type" default="confirmed" />
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "pmscheduleequipmentid"
})
@XmlRootElement(name = "MP7006_DeletePMScheduleEquipment_001")
public class MP7006_DeletePMScheduleEquipment_001
    extends BaseSchemaRequestElement
{

    @XmlElement(name = "PMSCHEDULEEQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected PMSCHEDULEEQUIPMENTID pmscheduleequipmentid;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;
    @XmlAttribute(name = "callname")
    protected String callname;
    @XmlAttribute(name = "action")
    protected String action;
    @XmlAttribute(name = "confirm_deleteall_pms_equip")
    protected String confirm_Deleteall_Pms_Equip;

    /**
     * Gets the value of the pmscheduleequipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link PMSCHEDULEEQUIPMENTID }
     *     
     */
    public PMSCHEDULEEQUIPMENTID getPMSCHEDULEEQUIPMENTID() {
        return pmscheduleequipmentid;
    }

    /**
     * Sets the value of the pmscheduleequipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PMSCHEDULEEQUIPMENTID }
     *     
     */
    public void setPMSCHEDULEEQUIPMENTID(PMSCHEDULEEQUIPMENTID value) {
        this.pmscheduleequipmentid = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.DELETE;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.PM_SCHEDULE_EQUIPMENT;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

    /**
     * Gets the value of the callname property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCallname() {
        if (callname == null) {
            return "DeletePMScheduleEquipment";
        } else {
            return callname;
        }
    }

    /**
     * Sets the value of the callname property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCallname(String value) {
        this.callname = value;
    }

    /**
     * Gets the value of the action property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAction() {
        if (action == null) {
            return "DeletePMScheduleEquipment";
        } else {
            return action;
        }
    }

    /**
     * Sets the value of the action property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAction(String value) {
        this.action = value;
    }

    /**
     * Gets the value of the confirm_Deleteall_Pms_Equip property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getConfirm_Deleteall_Pms_Equip() {
        if (confirm_Deleteall_Pms_Equip == null) {
            return "confirmed";
        } else {
            return confirm_Deleteall_Pms_Equip;
        }
    }

    /**
     * Sets the value of the confirm_Deleteall_Pms_Equip property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setConfirm_Deleteall_Pms_Equip(String value) {
        this.confirm_Deleteall_Pms_Equip = value;
    }

}
